%                   AN IMPROVED MATLAB FUNCTION FOR DESIGNING
%                        MULTILEVEL MULTIHARMONIC SIGNALS
% 
% Computer optimised multiharmonic signals are designed to match a specified 
% power spectrum as closely as possible. Two types of such signals can be designed
% using the Frequency Domain System Identification Toolbox in MATLAB. 
% 
% The first type is a multisine (sum of harmonics) signal; this can take any 
% value within the range between its minimum and maximum values. For linear 
% system identification, the relative phases between the harmonics are optimised 
% in order to minimise the peak-to-peak amplitude of the signal. 
% 
% The second type is a discrete-interval binary signal, in which the objective 
% of the optimisation is to maximise the amount of power in the specified harmonics.
% Since the signal is binary, the peak-to-peak amplitude can be clearly defined,
% and it is generally lower than that of a multisine signal with the same harmonic
% specification. However, for a binary signal, it is inevitable that some of 
% the total signal power appears in the non-specified harmonics. 
% 
% Multilevel multiharmonic signals are designed to retain the advantages of
% each type of signal, while reducing the disadvantages
% (A.S. McCormack, K.R. Godfrey and J.O. Flower (1995), "The design of 
% multilevel multiharmonic signals for system identification", IEEE 
% Transactions on Instrumentation and Measurement, Vol. IM-43, pp. 232-237). 
% The method described in this paper uses an algorithm based on swapping between
% the time and frequency domains, which maximises the minimum ratio between actual
% and specified Fourier coefficients. This may not be suitable for all applications,
% and recently, a modification has been done to optimise the Time Factor (TF) 
% of the signal instead. The Time Factor provides an indication of the time taken
% to achieve a minimum estimation accuracy of the frequency response of a system,
% at any of the specified harmonics (R. Pintelon and J. Schoukens (2001),
% "System Identification - A Frequency Domain Approach", IEEE Press, Section 4.2.1). 

